# Uniprot

This a module for direct querying on the [Uniprot](https://uniprot.org) database.

Currently there is a single module, but more modules are expected to be created in the future and so this command was created as a submodule.

This provides nearly all information as [`ggetrs info`](./info.md) but is significantly faster.

| Submodule | Description |
|-----------|-------------|
| [`query`](./uniprot/query.md) | Searches through descriptions on ENSEMBL|
